"use client";
import React, { useState, useEffect } from 'react';
import { ArrowUpIcon, ArrowDownIcon } from 'lucide-react';
import PropertyDetailsModal from './developerWaitingDetails/PropertyDetailsModal';

const DeveloperWaitingApproval = ({
  waitingUsersData,
  totalPostDetails,
  totalDeveloperPostDetails,
  totalDeveloperUnapproval,
  totalDeveloperApproval,
  onStatusChange,
}) => {
  const [selectedProperty, setSelectedProperty] = useState(null);
  const [sortDirection, setSortDirection] = useState('desc');
  const [sortedData, setSortedData] = useState([]);

  const sortData = (data, direction) => {
    // Create a flattened array of all posts with their developer information
    const flattenedPosts = data.reduce((acc, developer) => {
      const developerPosts = developer.post_details.map(post => ({
        ...post,
        developerName: developer.name,
        developer_id: developer.id,
        mobile_number: developer.mobile_number
      }));
      return [...acc, ...developerPosts];
    }, []);

    // Sort the flattened posts by date
    const sortedPosts = flattenedPosts.sort((a, b) => {
      const dateA = new Date(a.created_at || 0).getTime();
      const dateB = new Date(b.created_at || 0).getTime();
      return direction === 'asc' ? dateA - dateB : dateB - dateA;
    });

    // Regroup the sorted posts by developer
    const regroupedData = sortedPosts.reduce((acc, post) => {
      const existingDeveloper = acc.find(item => item.id === post.developer_id);
      
      if (existingDeveloper) {
        existingDeveloper.post_details.push({
          ...post,
          created_at: post.created_at,
          id: post.id,
          land_distance: post.land_distance,
          land_photos: post.land_photos,
          developer_project_amenities: post.developer_project_amenities,
          land_size: post.land_size,
          land_size_unit: post.land_size_unit,
          land_type: post.land_type,
          post_type: post.post_type,
          status: post.status,
          dimension: post.dimension,
          developer_project_details: post.developer_project_details
        });
      } else {
        acc.push({
          id: post.developer_id,
          name: post.developerName,
          mobile_number: post.mobile_number,
          post_details: [{
            ...post,
            created_at: post.created_at,
            id: post.id,
            land_distance: post.land_distance,
            land_photos: post.land_photos,
            developer_project_amenities: post.developer_project_amenities,
            land_size: post.land_size,
            land_size_unit: post.land_size_unit,
            land_type: post.land_type,
            post_type: post.post_type,
            status: post.status,
            dimension: post.dimension,
            developer_project_details: post.developer_project_details
          }]
        });
      }
      return acc;
    }, []);

    return regroupedData;
  };

  useEffect(() => {
    if (waitingUsersData) {
      const sorted = sortData(waitingUsersData, sortDirection);
      setSortedData(sorted);
    }
  }, [waitingUsersData, sortDirection]);

  const handleViewDetails = (developer, post) => {
    const propertyData = {
      id: post.id,
      location: `${post.land_distance[0]?.locality}, ${post.land_distance[0]?.city}`,
      price: post.developer_project_amenities?.[0]?.price 
        ? `₹${post.developer_project_amenities[0].price} ${post.developer_project_amenities[0].price_unit}`
        : `₹${post.land_price?.price} ${post.land_price?.per_unit}`,
      number: developer.mobile_number,
      status: post.status === null ? 'Rejected' : post.status === 1 ? 'Approved' : 'Pending',
      type: post.post_type,
      date: new Date(post.created_at).toLocaleDateString(),
      images: post.land_photos.map(photo => ({
        mainImg: photo.main_img,
        thumbImages: photo.thumbnails.map(thumb => thumb.thumb_photos)
      })),
      youtube: post.land_photos[0]?.youtube_link,
      drone: post.land_photos[0]?.drone_link,
      dimensions: post.dimension,
      landSize: `${post.land_size} ${post.land_size_unit}`,
      facing: post.land_distance?.[0]?.plot_facing || post.land_distance?.plot_facing,
      basicRequirements: JSON.parse(post.land_price?.basic_req || "[]"),
      distances: post.land_distance?.[0]?.distance_form || post.land_distance?.distance_form,
      projectAmenities: post.developer_project_amenities?.[0]?.project_amenity?.split(','),
      plotNumber: post.developer_project_amenities?.[0]?.plot_number,
      reraNo: post.developer_project_details?.[0]?.RERA_no,
      projectName: post.developer_project_details?.[0]?.project_name,
    };
    setSelectedProperty(propertyData);
  };

  const handleCloseModal = () => {
    setSelectedProperty(null);
  };

  const handleRejectedStatus = (postId) => {
    onStatusChange(postId, 'rejected');
  };

  const handleApproveStatus = (postId) => {
    onStatusChange(postId, 'approve');
  };

  const toggleSort = () => setSortDirection(prev => prev === 'asc' ? 'desc' : 'asc');

  return (
    <div className="flex flex-col space-y-6 p-4 sm:p-6">
      {/* Header Section */}
      <div className="flex flex-col gap-3 sm:flex-row sm:items-center sm:justify-between">
        <div className="flex items-center gap-2">
          <h1 className="text-xl sm:text-2xl font-semibold text-gray-900">
            Developers Waiting for Admin Approval
          </h1>
          <span className="text-xs bg-yellow-100 text-yellow-800 px-2 py-0.5 rounded-full font-semibold">
            Unapproved
          </span>
        </div>
      </div>

      {/* Statistics Grid */}
      <div className="grid gap-4 grid-cols-1 sm:grid-cols-2 lg:grid-cols-4">
        {/* Total Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Total Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalPostDetails || 0}</div>
            <p className="text-xs text-gray-600">+12% from last month</p>
          </div>
        </div>

        {/* Total Developers Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Total Developer Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalDeveloperPostDetails || 0}</div>
            <p className="text-xs text-gray-600">+3 this month</p>
          </div>
        </div>

        {/* Waiting Approvals Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Waiting Approvals</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalDeveloperUnapproval || 0}</div>
            <p className="text-xs text-gray-600">Awaiting admin review</p>
          </div>
        </div>

        {/* Developer Approved Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Approved Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 8c-1.657 0-3 .895-3 2s1.343 2 3 2 3 .895 3 2-1.343 2-3 2m0-8c1.11 0 2.08.402 2.599 1M12 8V7m0 1v8m0 0v1m0-1c-1.11 0-2.08-.402-2.599-1M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalDeveloperApproval || 0}</div>
            <p className="text-xs text-gray-600">Approved by Admin</p>
          </div>
        </div>
      </div>

      {/* Properties Table Section */}
      <div className="rounded-lg border border-gray-200 bg-white shadow-sm overflow-hidden">
        <div className="border-b border-gray-200 px-4 py-4 sm:px-6 flex justify-between items-center">
          <h2 className="text-lg font-semibold text-gray-900">Recent Unapproved Properties</h2>
          <button
            onClick={toggleSort}
            className="flex items-center space-x-2 px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
          >
            <span>Sort by Date</span>
            {sortDirection === 'asc' ? (
              <ArrowUpIcon className="h-4 w-4" />
            ) : (
              <ArrowDownIcon className="h-4 w-4" />
            )}
          </button>
        </div>
        <div className="overflow-x-auto">
          {sortedData.length > 0 ? (
            <table className="w-full">
              <thead>
                <tr className="border-b border-gray-200 bg-gray-50">
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Developer Name</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Land Type</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Land Size</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">City</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Price</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Details</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Actions</th>
                </tr>
              </thead>
              <tbody className="bg-white divide-y divide-gray-200">
                {sortedData.map((developer) =>
                  developer.post_details.map((post) => (
                    <tr key={`${developer.id}-${post.id}`} className="hover:bg-gray-50">
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-6">
                        {developer.name.charAt(0).toUpperCase() + developer.name.slice(1)}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                        {post.land_type?.charAt(0).toUpperCase() + post.land_type?.slice(1)}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-6">
                        {post.land_size} {post.land_size_unit}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                      {post.land_distance[0]?.city? post.land_distance[0].city.charAt(0).toUpperCase() + 
                      post.land_distance[0].city.slice(1): ""}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                        {post.developer_project_amenities?.[0]?.price 
                          ? `₹ ${post.developer_project_amenities[0].price} ${post.developer_project_amenities[0].price_unit}`
                          : `₹ ${post.land_price?.price} ${post.land_price?.per_unit}`}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm sm:px-6">
                        <div className="flex items-center gap-2 sm:gap-4">
                          <button 
                            onClick={() => handleViewDetails(developer, post)}
                            className="text-blue-600 hover:text-blue-900"
                            aria-label="View details"
                          >
                            <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
                              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M2.458 12C3.732 7.943 7.523 5 12 5c4.478 0 8.268 2.943 9.542 7-1.274 4.057-5.064 7-9.542 7-4.477 0-8.268-2.943-9.542-7z" />
                            </svg>
                          </button>
                        </div>
                      </td>

                      <td className="px-4 py-4 whitespace-nowrap text-sm sm:px-6">
                        <div className="flex items-center gap-2 sm:gap-4">
                          <button onClick={() => handleApproveStatus(post.id)} className="text-green-600 hover:text-green-900 flex items-center space-x-1">
                            <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
                            </svg>
                            <span className="hidden sm:inline">Approve</span>
                          </button>
                          <button onClick={() => handleRejectedStatus(post.id)} className="text-red-600 hover:text-red-900 flex items-center space-x-1">

<svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z" />
                        </svg>
                        <span className="hidden sm:inline">Reject</span>
                      </button>

                        </div>
                      </td>
                    </tr>
                  ))
                )}
              </tbody>
            </table>
          ) : (
            <p className="p-4">No developer users found.</p>
          )}
        </div>
      </div>

      {/* Property Details Modal */}
      {selectedProperty && (
        <PropertyDetailsModal 
          property={selectedProperty} 
          onClose={handleCloseModal} 
        />
      )}
    </div>
  );
};

export default DeveloperWaitingApproval;